import { Body, Controller, Get, Post } from '@nestjs/common';
import { Unprotected } from 'src/core/guards';
import { Pagination } from 'src/core/response';
import { PaginationResponse } from 'src/core/response/domain/ok-response.interface';
import { LoginRequest } from '../domain/entities/request.interface';
import { User } from '../domain/entities/user.interface';
import { AuthService } from '../domain/services/auth.service';

@Controller('auth')
export class AuthController {
  constructor(private readonly service: AuthService) {}

  @Unprotected()
  @Post()
  login(@Body() body: LoginRequest) {
    return this.service.createAccessToken(body);
  }

  @Get()
  user() {
    return this.service.getUser();
  }

  @Pagination()
  @Get('/all')
  async users(): Promise<PaginationResponse<User>> {
    return {
      data: await this.service.getUsers(),
      total: 101,
    };
  }
}
